Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(122)

Unified Diff: chromeos/dbus/shill_ipconfig_client.cc

Issue 10915106: Renaming instances of "flimflam" with "shill", now that we're only (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Upload after merge Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chromeos/dbus/shill_ipconfig_client.h ('k') | chromeos/dbus/shill_ipconfig_client_unittest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chromeos/dbus/shill_ipconfig_client.cc
diff --git a/chromeos/dbus/flimflam_ipconfig_client.cc b/chromeos/dbus/shill_ipconfig_client.cc
similarity index 82%
rename from chromeos/dbus/flimflam_ipconfig_client.cc
rename to chromeos/dbus/shill_ipconfig_client.cc
index e3f8cbe6e3f62290b70420b8aafba18f07ac9c6d..509696bde5ef9ebbe190f0abe772eda55d8c7bd2 100644
--- a/chromeos/dbus/flimflam_ipconfig_client.cc
+++ b/chromeos/dbus/shill_ipconfig_client.cc
@@ -2,7 +2,7 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#include "chromeos/dbus/flimflam_ipconfig_client.h"
+#include "chromeos/dbus/shill_ipconfig_client.h"
#include "base/bind.h"
#include "base/message_loop.h"
@@ -19,12 +19,12 @@ namespace chromeos {
namespace {
-// The FlimflamIPConfigClient implementation.
-class FlimflamIPConfigClientImpl : public FlimflamIPConfigClient {
+// The ShillIPConfigClient implementation.
+class ShillIPConfigClientImpl : public ShillIPConfigClient {
public:
- explicit FlimflamIPConfigClientImpl(dbus::Bus* bus);
+ explicit ShillIPConfigClientImpl(dbus::Bus* bus);
- // FlimflamIPConfigClient overrides:
+ // ShillIPConfigClient overrides:
virtual void SetPropertyChangedHandler(
const dbus::ObjectPath& ipconfig_path,
const PropertyChangedHandler& handler) OVERRIDE;
@@ -49,10 +49,10 @@ class FlimflamIPConfigClientImpl : public FlimflamIPConfigClient {
const dbus::ObjectPath& ipconfig_path) OVERRIDE;
private:
- typedef std::map<std::string, FlimflamClientHelper*> HelperMap;
+ typedef std::map<std::string, ShillClientHelper*> HelperMap;
- // Returns the corresponding FlimflamClientHelper for the profile.
- FlimflamClientHelper* GetHelper(const dbus::ObjectPath& ipconfig_path) {
+ // Returns the corresponding ShillClientHelper for the profile.
+ ShillClientHelper* GetHelper(const dbus::ObjectPath& ipconfig_path) {
HelperMap::iterator it = helpers_.find(ipconfig_path.value());
if (it != helpers_.end())
return it->second;
@@ -60,7 +60,7 @@ class FlimflamIPConfigClientImpl : public FlimflamIPConfigClient {
// There is no helper for the profile, create it.
dbus::ObjectProxy* object_proxy =
bus_->GetObjectProxy(flimflam::kFlimflamServiceName, ipconfig_path);
- FlimflamClientHelper* helper = new FlimflamClientHelper(bus_, object_proxy);
+ ShillClientHelper* helper = new ShillClientHelper(bus_, object_proxy);
helper->MonitorPropertyChanged(flimflam::kFlimflamIPConfigInterface);
helpers_.insert(HelperMap::value_type(ipconfig_path.value(), helper));
return helper;
@@ -70,26 +70,26 @@ class FlimflamIPConfigClientImpl : public FlimflamIPConfigClient {
HelperMap helpers_;
STLValueDeleter<HelperMap> helpers_deleter_;
- DISALLOW_COPY_AND_ASSIGN(FlimflamIPConfigClientImpl);
+ DISALLOW_COPY_AND_ASSIGN(ShillIPConfigClientImpl);
};
-FlimflamIPConfigClientImpl::FlimflamIPConfigClientImpl(dbus::Bus* bus)
+ShillIPConfigClientImpl::ShillIPConfigClientImpl(dbus::Bus* bus)
: bus_(bus),
helpers_deleter_(&helpers_) {
}
-void FlimflamIPConfigClientImpl::SetPropertyChangedHandler(
+void ShillIPConfigClientImpl::SetPropertyChangedHandler(
const dbus::ObjectPath& ipconfig_path,
const PropertyChangedHandler& handler) {
GetHelper(ipconfig_path)->SetPropertyChangedHandler(handler);
}
-void FlimflamIPConfigClientImpl::ResetPropertyChangedHandler(
+void ShillIPConfigClientImpl::ResetPropertyChangedHandler(
const dbus::ObjectPath& ipconfig_path) {
GetHelper(ipconfig_path)->ResetPropertyChangedHandler();
}
-void FlimflamIPConfigClientImpl::GetProperties(
+void ShillIPConfigClientImpl::GetProperties(
const dbus::ObjectPath& ipconfig_path,
const DictionaryValueCallback& callback) {
dbus::MethodCall method_call(flimflam::kFlimflamIPConfigInterface,
@@ -97,7 +97,7 @@ void FlimflamIPConfigClientImpl::GetProperties(
GetHelper(ipconfig_path)->CallDictionaryValueMethod(&method_call, callback);
}
-base::DictionaryValue* FlimflamIPConfigClientImpl::CallGetPropertiesAndBlock(
+base::DictionaryValue* ShillIPConfigClientImpl::CallGetPropertiesAndBlock(
const dbus::ObjectPath& ipconfig_path) {
dbus::MethodCall method_call(flimflam::kFlimflamIPConfigInterface,
flimflam::kGetPropertiesFunction);
@@ -105,7 +105,7 @@ base::DictionaryValue* FlimflamIPConfigClientImpl::CallGetPropertiesAndBlock(
&method_call);
}
-void FlimflamIPConfigClientImpl::Refresh(
+void ShillIPConfigClientImpl::Refresh(
const dbus::ObjectPath& ipconfig_path,
const VoidDBusMethodCallback& callback) {
dbus::MethodCall method_call(flimflam::kFlimflamIPConfigInterface,
@@ -113,7 +113,7 @@ void FlimflamIPConfigClientImpl::Refresh(
GetHelper(ipconfig_path)->CallVoidMethod(&method_call, callback);
}
-void FlimflamIPConfigClientImpl::SetProperty(
+void ShillIPConfigClientImpl::SetProperty(
const dbus::ObjectPath& ipconfig_path,
const std::string& name,
const base::Value& value,
@@ -155,7 +155,7 @@ void FlimflamIPConfigClientImpl::SetProperty(
GetHelper(ipconfig_path)->CallVoidMethod(&method_call, callback);
}
-void FlimflamIPConfigClientImpl::ClearProperty(
+void ShillIPConfigClientImpl::ClearProperty(
const dbus::ObjectPath& ipconfig_path,
const std::string& name,
const VoidDBusMethodCallback& callback) {
@@ -166,7 +166,7 @@ void FlimflamIPConfigClientImpl::ClearProperty(
GetHelper(ipconfig_path)->CallVoidMethod(&method_call, callback);
}
-void FlimflamIPConfigClientImpl::Remove(
+void ShillIPConfigClientImpl::Remove(
const dbus::ObjectPath& ipconfig_path,
const VoidDBusMethodCallback& callback) {
dbus::MethodCall method_call(flimflam::kFlimflamIPConfigInterface,
@@ -174,22 +174,22 @@ void FlimflamIPConfigClientImpl::Remove(
GetHelper(ipconfig_path)->CallVoidMethod(&method_call, callback);
}
-bool FlimflamIPConfigClientImpl::CallRemoveAndBlock(
+bool ShillIPConfigClientImpl::CallRemoveAndBlock(
const dbus::ObjectPath& ipconfig_path) {
dbus::MethodCall method_call(flimflam::kFlimflamIPConfigInterface,
flimflam::kRemoveConfigFunction);
return GetHelper(ipconfig_path)->CallVoidMethodAndBlock(&method_call);
}
-// A stub implementation of FlimflamIPConfigClient.
-class FlimflamIPConfigClientStubImpl : public FlimflamIPConfigClient {
+// A stub implementation of ShillIPConfigClient.
+class ShillIPConfigClientStubImpl : public ShillIPConfigClient {
public:
- FlimflamIPConfigClientStubImpl() : weak_ptr_factory_(this) {}
+ ShillIPConfigClientStubImpl() : weak_ptr_factory_(this) {}
- virtual ~FlimflamIPConfigClientStubImpl() {}
+ virtual ~ShillIPConfigClientStubImpl() {}
///////////////////////////////////////////////
- // FlimflamIPConfigClient overrides:
+ // ShillIPConfigClient overrides:
virtual void SetPropertyChangedHandler(
const dbus::ObjectPath& ipconfig_path,
const PropertyChangedHandler& handler) OVERRIDE {}
@@ -203,7 +203,7 @@ class FlimflamIPConfigClientStubImpl : public FlimflamIPConfigClient {
virtual void GetProperties(const dbus::ObjectPath& ipconfig_path,
const DictionaryValueCallback& callback) OVERRIDE {
MessageLoop::current()->PostTask(
- FROM_HERE, base::Bind(&FlimflamIPConfigClientStubImpl::PassProperties,
+ FROM_HERE, base::Bind(&ShillIPConfigClientStubImpl::PassProperties,
weak_ptr_factory_.GetWeakPtr(),
callback));
}
@@ -249,25 +249,25 @@ class FlimflamIPConfigClientStubImpl : public FlimflamIPConfigClient {
// Note: This should remain the last member so it'll be destroyed and
// invalidate its weak pointers before any other members are destroyed.
- base::WeakPtrFactory<FlimflamIPConfigClientStubImpl> weak_ptr_factory_;
+ base::WeakPtrFactory<ShillIPConfigClientStubImpl> weak_ptr_factory_;
- DISALLOW_COPY_AND_ASSIGN(FlimflamIPConfigClientStubImpl);
+ DISALLOW_COPY_AND_ASSIGN(ShillIPConfigClientStubImpl);
};
} // namespace
-FlimflamIPConfigClient::FlimflamIPConfigClient() {}
+ShillIPConfigClient::ShillIPConfigClient() {}
-FlimflamIPConfigClient::~FlimflamIPConfigClient() {}
+ShillIPConfigClient::~ShillIPConfigClient() {}
// static
-FlimflamIPConfigClient* FlimflamIPConfigClient::Create(
+ShillIPConfigClient* ShillIPConfigClient::Create(
DBusClientImplementationType type,
dbus::Bus* bus) {
if (type == REAL_DBUS_CLIENT_IMPLEMENTATION)
- return new FlimflamIPConfigClientImpl(bus);
+ return new ShillIPConfigClientImpl(bus);
DCHECK_EQ(STUB_DBUS_CLIENT_IMPLEMENTATION, type);
- return new FlimflamIPConfigClientStubImpl();
+ return new ShillIPConfigClientStubImpl();
}
} // namespace chromeos
« no previous file with comments | « chromeos/dbus/shill_ipconfig_client.h ('k') | chromeos/dbus/shill_ipconfig_client_unittest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698